Data Generation
===============

.. currentmodule:: bcselector.data_generation

MatrixGenerator
---------------

.. autoclass:: MatrixGenerator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MatrixGenerator.generate

   .. rubric:: Methods Documentation

   .. automethod:: generate

DataFrameGenerator
------------------

.. autoclass:: DataFrameGenerator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DataFrameGenerator.generate

   .. rubric:: Methods Documentation

   .. automethod:: generate